#!/bin/bash
# This script adds an Internal DNS A record to the DNS server zone file (common::add_dns_a_record_internal)

# Bolt environment variables
NETWORK="${PT_network}"
ADD_A_RECORD="${PT_add_a_record_bool}"
IP="${PT_ip_with_cidr}"
HOSTNAME="${PT_dns_hostname}"
TTL="${PT_dns_ttl}"

# Check if A record addition is requested
if [ "$ADD_A_RECORD" != "true" ] || [ "$NETWORK" != "internal-moeny" ]; then
    echo '{"status": "skipped", "message": "Skipping internal A Record - either not requested or not on internal-moeny network"}'
    exit 0
fi

# Check if required parameters are provided
if [ -z "$IP" ] || [ -z "$HOSTNAME" ] || [ -z "$TTL" ]; then
    echo '{"status": "failure", "message": "Error: Both ip_with_cidr, dns_hostname and ttl parameters must be provided"}'
    exit 1
fi

# Create DNS A record
IP_ADDRESS=$(echo ${IP} | cut -d'/' -f1)
nsupdate -k "./keys/tsig-internal.key" << EOF
server ns99.moeny.internal
debug yes
zone moeny.internal
update add ${HOSTNAME}.moeny.internal ${TTL} A ${IP_ADDRESS}
send
EOF

# Force zone file update on DNS server
ssh moeny@ns99.moeny.internal "sudo rndc sync moeny.internal"

echo '{"status": "success", "message": "Internal A Record successfully added."}'